# androtools

[![PyPI](https://img.shields.io/pypi/v/androtools?style=for-the-badge)](https://pypi.org/project/androtools/) ![PyPI - Status](https://img.shields.io/pypi/status/androtools?style=for-the-badge) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/androtools?style=for-the-badge)  ![PyPI - Downloads](https://img.shields.io/pypi/dw/androtools?style=for-the-badge) ![PyPI - License](https://img.shields.io/pypi/l/androtools?style=for-the-badge)

- 命令封装
    - 优先 adb
- 业务逻辑封装，business
- adb 连接多个模拟器
  - usb 的方式
  - 本地模拟器
  - 稳定连接

参考：
- https://github.com/Genymobile/scrcpy，控制手机